searchData={"content_type":"text/markdown","items":[{"doc":"Provides an Ueberauth strategy for authenticating with Okta.","ref":"Ueberauth.Strategy.Okta.html","title":"Ueberauth.Strategy.Okta","type":"module"},{"doc":"Include the provider in your configuration for Ueberauth with any\napplicable configuration options (Okta and OAuth2 options are supported):\n\n```elixir\nconfig :ueberauth, Ueberauth,\nproviders: [\n  okta: {Ueberauth.Strategy.Okta, [client_id: \"12345\"]}\n]\n```\n\n**Note**: Provider options are evaluated at compile time by default (see [Plug](https://hexdocs.pm/plug/1.14.0/Plug.html#module-plugs))\nso if you use `runtime.exs` or another mechanism to load options into the\nApplication environment, you'll want to use the `Ueberauth.Strategy.Okta.OAuth`\nscope. See `Ueberauth.Strategy.Okta.OAuth` module doc for more details.\n\n#","ref":"Ueberauth.Strategy.Okta.html#module-setup","title":"Setup - Ueberauth.Strategy.Okta","type":"module"},{"doc":"* `:oauth2_module` - OAuth module to use (default: `Ueberauth.Strategy.Okta.OAuth`)\n* `:oauth2_params` - query parameters for the oauth request. See [Okta OAuth2\ndocumentation](https://developer.okta.com/docs/api/resources/oidc#authorize)\nfor list of parameters. _Note that not all parameters are compatible with this flow_.\n(default: `[scope: \"openid email profile\"]`)\n* `:uid_field` - default: `:sub`","ref":"Ueberauth.Strategy.Okta.html#module-okta-options","title":"Okta Options - Ueberauth.Strategy.Okta","type":"module"},{"doc":"Includes the credentials from the Okta response.","ref":"Ueberauth.Strategy.Okta.html#credentials/1","title":"Ueberauth.Strategy.Okta.credentials/1","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.Okta.html#default_options/0","title":"Ueberauth.Strategy.Okta.default_options/0","type":"function"},{"doc":"Stores the raw information (including the token) obtained from the Okta callback.","ref":"Ueberauth.Strategy.Okta.html#extra/1","title":"Ueberauth.Strategy.Okta.extra/1","type":"function"},{"doc":"Cleans up the private area of the connection used for passing the raw Okta response around during the callback.","ref":"Ueberauth.Strategy.Okta.html#handle_cleanup!/1","title":"Ueberauth.Strategy.Okta.handle_cleanup!/1","type":"function"},{"doc":"Handles the initial redirect to the okta authentication page.\n\nSupports `state` and `redirect_uri` params which are required for Okta\n/authorize request. These will also be generated if omitted.\n`redirect_uri` from the strategy config will take precedence over value\nprovided here","ref":"Ueberauth.Strategy.Okta.html#handle_request!/1","title":"Ueberauth.Strategy.Okta.handle_request!/1","type":"function"},{"doc":"Fetches the fields to populate the info section of the `Ueberauth.Auth` struct.","ref":"Ueberauth.Strategy.Okta.html#info/1","title":"Ueberauth.Strategy.Okta.info/1","type":"function"},{"doc":"Fetches the uid field from the Okta response. This defaults to the option `uid_field` which in-turn defaults to `sub`","ref":"Ueberauth.Strategy.Okta.html#uid/1","title":"Ueberauth.Strategy.Okta.uid/1","type":"function"},{"doc":"An implementation of OAuth2 for Okta.\n\nSupported options:\n* `:site` - (**required**) Full request URL\n* `:client_id` - (**required**) Okta client ID\n* `:client_secret` - (**required**) Okta client secret\n* `:authorize_url` - default:  \"/oauth2/v1/authorize\",\n* `:token_url` - default:  \"/oauth2/v1/token\",\n* `:userinfo_url` - default:  \"/oauth2/v1/userinfo\"\n* `:authorization_server_id` - If supplied, URLs for the request will be adjusted to include\n  the custom Okta Authorization Server ID\n* Any `OAuth2.Client` option\n\nThese options can be provided with the provider settings, or under the `Ueberauth.Strategy.Okta.OAuth` scope:\n\n```elixir\nconfig :ueberauth, Ueberauth.Strategy.Okta.OAuth,\nsite: \"https://your-doman.okta.com\"\nclient_id: System.get_env(\"OKTA_CLIENT_ID\"),\nclient_secret: System.get_env(\"OKTA_CLIENT_SECRET\")\n```\n\n#","ref":"Ueberauth.Strategy.Okta.OAuth.html","title":"Ueberauth.Strategy.Okta.OAuth","type":"module"},{"doc":"To support multiple providers, scope the settings to the same provider key you\nused when configuring `Ueberauth`:\n\n```elixir\nconfig :ueberauth, Ueberauth,\nproviders: [\n  okta: {Ueberauth.Strategy.Okta, []}\n]\n\nconfig :ueberauth, Ueberauth.Strategy.Okta.OAuth,\nokta: [\n  site: \"https://your-doman.okta.com\"\n  client_id: System.get_env(\"OKTA_CLIENT_ID\"),\n  client_secret: System.get_env(\"OKTA_CLIENT_SECRET\")\n]\n```\n\nScoped OAuth settings will take precedence over the global settings","ref":"Ueberauth.Strategy.Okta.OAuth.html#module-multiple-providers-multitenant","title":"Multiple Providers (Multitenant) - Ueberauth.Strategy.Okta.OAuth","type":"module"},{"doc":"Provides the authorize url for the request phase of Ueberauth.","ref":"Ueberauth.Strategy.Okta.OAuth.html#authorize_url!/2","title":"Ueberauth.Strategy.Okta.OAuth.authorize_url!/2","type":"function"},{"doc":"Construct a client for requests to Okta.\n\nIntended for use from Ueberauth.Strategy.Okta but supplying options for usage\noutside the normal callback phase of Ueberauth. See OAuth2.Client.t() for\navailable options.","ref":"Ueberauth.Strategy.Okta.OAuth.html#client/1","title":"Ueberauth.Strategy.Okta.OAuth.client/1","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.Okta.OAuth.html#get_token/2","title":"Ueberauth.Strategy.Okta.OAuth.get_token/2","type":"function"},{"doc":"","ref":"Ueberauth.Strategy.Okta.OAuth.html#get_user_info/2","title":"Ueberauth.Strategy.Okta.OAuth.get_user_info/2","type":"function"},{"doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"* Fix an issue looking up provider options in the Application config which\n  may be stored or referenced as a string (thanks @giddie :heart:)","ref":"changelog.html#v1-1-1-2023-01-25","title":"v1.1.1 - 2023-01-25 - Changelog","type":"extras"},{"doc":"This essentially negates v1.0.0 and adds back the `Ueberauth.Strategy.Okta.OAuth`\nconfiguration scope to support better runtime option management. Both this scope\nand using the `:providers` key in Ueberauth config are supported.\n\n* Fix support with `runtime.exs` files and runtime evaluations of options.\n* Support `:providers` in `Ueberauth.Strategy.Okta.OAuth` to allow for\n  multi-tenant support","ref":"changelog.html#v1-1-0-2022-12-29","title":"v1.1.0 - 2022-12-29 - Changelog","type":"extras"},{"doc":"This is a breaking change that removes the ability to set OAuth settings in the\napplication environment via `Ueberauth.Strategy.Okta.OAuth` and instead relies\non the settings coming in from the Ueberauth `:providers` setup.\n\n* Support `:authorization_server_id` for custom Okta Authorization Servers. This will\n  add the id to the default urls used in the process (Thanks @giddie!)","ref":"changelog.html#v1-0-0-2022-11-28","title":"v1.0.0 - 2022-11-28 - Changelog","type":"extras"},{"doc":"* Support multi-tenant applications by allowing dynamic Okta configs in the conn\n  (Thanks @ryanzidago :heart:)","ref":"changelog.html#v0-3-1-2022-08-12","title":"v0.3.1 - 2022-08-12 - Changelog","type":"extras"},{"doc":"Potentially breaking changes\n\n* bump `ueberauth` 0.7.0 - If you require >= 0.6 then you may need to\n  adjust things before updating\n  * support CSRF attack protection bia the `with_state_param` from ueberauth (thanks @Jonathan-Arias!)","ref":"changelog.html#v0-3-0-2021-07-30","title":"v0.3.0 - 2021-07-30 - Changelog","type":"extras"},{"doc":"No breaking changes\n\n* Fix some compiler warnings (Thanks @zillou!)\n* Bump development/release deps","ref":"changelog.html#v0-2-1-2021-06-01","title":"v0.2.1 - 2021-06-01 - Changelog","type":"extras"},{"doc":"Addresses issues between Okta API and OAuth2 implementation (Thanks @Deconstrained)\n\n* The client credentials are included in both the body (params) and in the basic authorization header; Okta will issue a 403 in response to this.\n* Okta's response containing the access token is JSON-encoded, and since oauth2 does not by default support the JSON mimetype, the JSON string containing the token is treated as the token itself, which results in a 401 when making the final request to authenticate the user back to Okta.","ref":"changelog.html#v0-2-0-2020-10-19","title":"v0.2.0 - 2020-10-19 - Changelog","type":"extras"},{"doc":"* Initial Release","ref":"changelog.html#v0-1-0-2018-04-25","title":"v0.1.0 - 2018-04-25 - Changelog","type":"extras"},{"doc":"# MIT License\n\nCopyright (c) 2018 Jon Carstens\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"# Überauth Okta\n\n[![Module Version](https://img.shields.io/hexpm/v/ueberauth_okta.svg)](https://hex.pm/packages/ueberauth_okta)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/ueberauth_okta/)\n[![Total Download](https://img.shields.io/hexpm/dt/ueberauth_okta.svg)](https://hex.pm/packages/ueberauth_okta)\n[![License](https://img.shields.io/hexpm/l/ueberauth_okta.svg)](https://github.com/jjcarstens/ueberauth_okta/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/jjcarstens/ueberauth_okta.svg)](https://github.com/jjcarstens/ueberauth_okta/commits/master)\n\n> Okta strategy for Überauth.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"Add `:ueberauth_okta` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:ueberauth_okta, \"~> 1.0\"}]\nend\n```","ref":"readme.html#installation","title":"Installation - Overview","type":"extras"},{"doc":"You'll need to register a new application with Okta and get the `client_id`\nand `client_secret`. That setup is out of the scope of this library, but some\nnotes to remember are:\n\n  * Ensure `Authorization Code` grant type is enabled\n  * You have valid `Login Redirect Urls` listed for the app that correctly\n    reference your callback route(s)\n  * `user` or `group` permissions may need to be added to your Okta app\n    before successfully authenticating\n\nInclude the provider in your configuration for Ueberauth with any\napplicable configuration options (Okta and OAuth2 options are supported):\n\n```elixir\nconfig :ueberauth, Ueberauth,\n  providers: [\n    okta: {Ueberauth.Strategy.Okta, [client_id: \"12345\"]}\n  ]\n```\n\n**Note**: Provider options are evaluated at compile time by default (see [Plug](https://hexdocs.pm/plug/1.14.0/Plug.html#module-plugs))\nso if you use `runtime.exs` or another mechanism to load options into the\nApplication environment, you'll want to use the `Ueberauth.Strategy.Okta.OAuth`\nscope. See below for details\n\n#","ref":"readme.html#setup","title":"Setup - Overview","type":"extras"},{"doc":"* `:oauth2_module` - OAuth module to use (default: `Ueberauth.Strategy.Okta.OAuth`)\n* `:oauth2_params` - query parameters for the oauth request. See [Okta OAuth2\n  documentation](https://developer.okta.com/docs/api/resources/oidc#authorize)\n  for list of parameters. _Note that not all parameters are compatible with this flow_.\n  (default: `[scope: \"openid email profile\"]`)\n* `:uid_field` - default: `:sub`\n\n#","ref":"readme.html#okta-options","title":"Okta Options - Overview","type":"extras"},{"doc":"The default OAuth2 module for making the requests is `Ueberauth.Strategy.Okta.OAuth`\nwhich uses the following options:\n\n* `:site` - (**required**) Full request URL\n* `:client_id` - (**required**) Okta client ID\n* `:client_secret` - (**required**) Okta client secret\n* `:authorize_url` - default:  \"/oauth2/v1/authorize\",\n* `:token_url` - default:  \"/oauth2/v1/token\",\n* `:userinfo_url` - default:  \"/oauth2/v1/userinfo\"\n* `:authorization_server_id` - If supplied, URLs for the request will be adjusted to include\n    the custom Okta Authorization Server ID\n* Any `OAuth2.Client.t()` option\n\nThese options can be provided with the provider settings, or under the `Ueberauth.Strategy.Okta.OAuth` scope:\n\n```elixir\nconfig :ueberauth, Ueberauth.Strategy.Okta.OAuth,\n  site: \"https://your-doman.okta.com\"\n  client_id: System.get_env(\"OKTA_CLIENT_ID\"),\n  client_secret: System.get_env(\"OKTA_CLIENT_SECRET\")\n```\n\n##","ref":"readme.html#oauth2-options","title":"OAuth2 options - Overview","type":"extras"},{"doc":"To support multiple providers, scope the settings to the same provider key you\nused when configuring `Ueberauth`:\n\n```elixir\nconfig :ueberauth, Ueberauth,\n  providers: [\n    okta: {Ueberauth.Strategy.Okta, []}\n  ]\n\nconfig :ueberauth, Ueberauth.Strategy.Okta.OAuth,\n  okta: [\n    site: \"https://your-doman.okta.com\"\n    client_id: System.get_env(\"OKTA_CLIENT_ID\"),\n    client_secret: System.get_env(\"OKTA_CLIENT_SECRET\")\n  ]\n```\n\nScoped OAuth settings will take precedence over the global settings\n\n#","ref":"readme.html#multiple-providers-multitenant","title":"Multiple Providers (Multitenant) - Overview","type":"extras"},{"doc":"If you haven't already, create a pipeline and setup routes for your callback handler\n\n```elixir\npipeline :auth do\n  plug Ueberauth\nend\nscope \"/auth\" do\n  pipe_through [:browser, :auth]\n  get \"/:provider/callback\", AuthController, :callback\nend\n```\n\nCreate an endpoint for the callback where you will handle the `Ueberauth.Auth` struct\n\n```elixir\ndefmodule MyApp.AuthController do\n  use MyApp.Web, :controller\n  def callback_phase(%{ assigns: %{ ueberauth_failure: fails } } = conn, _params) do\n    # do things with the failure\n  end\n  def callback_phase(%{ assigns: %{ ueberauth_auth: auth } } = conn, params) do\n    # do things with the auth\n  end\nend\n```","ref":"readme.html#adding-request-flow","title":"Adding Request Flow - Overview","type":"extras"},{"doc":"Copyright (c) 2022 Jon Carstens\n\nReleased under the [MIT License](./LICENSE.md).","ref":"readme.html#copyright-and-license","title":"Copyright and License - Overview","type":"extras"}]}